==> mule-module-artifact-activation-4.8.8-20250703.202528-3-sources.jar: org/mule/runtime/module/artifact/activation/api/descriptor/DeployableArtifactDescriptorCreator.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.module.artifact.activation.api.descriptor;

import org.mule.api.annotation.NoImplement;
import org.mule.runtime.module.artifact.api.descriptor.ApplicationDescriptor;
import org.mule.runtime.module.artifact.api.descriptor.DeployableArtifactDescriptor;
import org.mule.runtime.module.artifact.api.descriptor.DomainDescriptor;

import java.util.Optional;
import java.util.Properties;

/**
 * Creates an instance of a deployable artifact descriptor.
 *
 * @param <D> the concrete type of deployable artifact descriptor (application or domain) to resolve.
 * @since 4.5
 */
@NoImplement
public interface DeployableArtifactDescriptorCreator<D extends DeployableArtifactDescriptor> {

  /**
   * @return a default creator for {@link ApplicationDescriptor}s.
   */
  static DeployableArtifactDescriptorCreator<ApplicationDescriptor> applicationDescriptorCreator() {
    return new DeployableArtifactDescriptorCreator<ApplicationDescriptor>() {

      @Override
      public ApplicationDescriptor create(String name) {
        return new ApplicationDescriptor(name);
      }

      @Override
      public ApplicationDescriptor create(String name, Optional<Properties> deploymentProperties) {
        return new ApplicationDescriptor(name, deploymentProperties);
      }

    };
  }

  /**
   * @return a default creator for {@link DomainDescriptor}s.
   */
  static DeployableArtifactDescriptorCreator<DomainDescriptor> domainDescriptorCreator() {
    return new DeployableArtifactDescriptorCreator<DomainDescriptor>() {

      @Override
      public DomainDescriptor create(String name) {
        return new DomainDescriptor(name);
      }

      @Override
      public DomainDescriptor create(String name, Optional<Properties> deploymentProperties) {
        return new DomainDescriptor(name, deploymentProperties);
      }

    };
  }

  /**
   * Creates a deployable artifact descriptor with the given name.
   *
   * @param name artifact name. Non-empty.
   * @return a deployable artifact descriptor.
   */
  D create(String name);

  /**
   * Creates a deployable artifact descriptor with the given name and deployment properties.
   *
   * @param name                 artifact name. Non-empty.
   * @param deploymentProperties deployment properties.
   * @return a deployable artifact descriptor.
   */
  D create(String name, Optional<Properties> deploymentProperties);

}

==> mule-module-artifact-activation-4.10.2-20251119.205816-22-sources.jar: org/mule/runtime/module/artifact/activation/api/descriptor/DeployableArtifactDescriptorCreator.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.module.artifact.activation.api.descriptor;

import org.mule.api.annotation.NoImplement;
import org.mule.runtime.module.artifact.api.descriptor.ApplicationDescriptor;
import org.mule.runtime.module.artifact.api.descriptor.DeployableArtifactDescriptor;
import org.mule.runtime.module.artifact.api.descriptor.DomainDescriptor;

import java.util.Optional;
import java.util.Properties;

/**
 * Creates an instance of a deployable artifact descriptor.
 *
 * @param <D> the concrete type of deployable artifact descriptor (application or domain) to resolve.
 * @since 4.5
 */
@NoImplement
public interface DeployableArtifactDescriptorCreator<D extends DeployableArtifactDescriptor> {

  /**
   * @return a default creator for {@link ApplicationDescriptor}s.
   */
  static DeployableArtifactDescriptorCreator<ApplicationDescriptor> applicationDescriptorCreator() {
    return new DeployableArtifactDescriptorCreator<>() {

      @Override
      public ApplicationDescriptor create(String name) {
        return new ApplicationDescriptor(name);
      }

      @Override
      public ApplicationDescriptor create(String name, Optional<Properties> deploymentProperties) {
        return new ApplicationDescriptor(name, deploymentProperties);
      }

    };
  }

  /**
   * @return a default creator for {@link DomainDescriptor}s.
   */
  static DeployableArtifactDescriptorCreator<DomainDescriptor> domainDescriptorCreator() {
    return new DeployableArtifactDescriptorCreator<>() {

      @Override
      public DomainDescriptor create(String name) {
        return new DomainDescriptor(name);
      }

      @Override
      public DomainDescriptor create(String name, Optional<Properties> deploymentProperties) {
        return new DomainDescriptor(name, deploymentProperties);
      }

    };
  }

  /**
   * Creates a deployable artifact descriptor with the given name.
   *
   * @param name artifact name. Non-empty.
   * @return a deployable artifact descriptor.
   */
  D create(String name);

  /**
   * Creates a deployable artifact descriptor with the given name and deployment properties.
   *
   * @param name                 artifact name. Non-empty.
   * @param deploymentProperties deployment properties.
   * @return a deployable artifact descriptor.
   */
  D create(String name, Optional<Properties> deploymentProperties);

}
